@@ -653,12 +653,12 @@ class Assignment(Base):
     # - online_text_entry (Текстовая запись)
     # - online_upload (Загрузки файла)
     # - online_url (URL-адрес веб-сайта)
-    submission_type = Column(String(255))
+    submission_types = Column(String(255))
 
-    @validates('submission_type')
-    def validate_submission_type(self, key, value):
+    @validates('submission_types')
+    def validate_submission_types(self, key, value):
         """
-        Значением submission_type может быть следующие значениям:
+        Значением submission_types может быть следующие значениям:
         - discussion_topic (???)
         - external_tool (Внешний инструмент)
         - none (Нет отправки)
